HistorianFu = AceLibrary("AceAddon-2.0"):new("FuBarPlugin-2.0", "AceEvent-2.0", "AceDB-2.0");
local tablet = AceLibrary("Tablet-2.0");

HistorianFu:RegisterDB("HistorianFuDB");


-- *************************************
-- * Set up defaults / addon options
-- *************************************
HistorianFu.hasIcon = "Interface\\Icons\\INV_Scroll_05";
HistorianFu.hideWithoutStandby = true;
HistorianFu.independentProfile = false;
HistorianFu.tooltipHiddenWhenEmpty = true;


-- *************************************
-- * Properties
-- *************************************
function HistorianFu:IsShowingTooltip()
	return Historian:IsShowingTooltip();
end;
 
function HistorianFu:ToggleShowingTooltip()
	Historian:ToggleShowingTooltip();
	self:Update();
end;


-- *************************************
-- * Menu options
-- *************************************
HistorianFu.OnMenuRequest = {
	type = 'group',
	args = {
		showTooltip = {
			type = "toggle",
			name = "Show tooltip on enemies",
			desc = "Displays certain statistics when your mouse is over known enemies.",
			get = "IsShowingTooltip",
			set = "ToggleShowingTooltip",
		},
	}
}
 

-- *************************************
-- * OnInitialize
-- *************************************
function HistorianFu:OnInitialize()
	self:RegisterEvent("Historian_Updated", "OnStatsUpdated");
end;
 
 
-- *************************************
-- * OnDataUpdate
-- *************************************
function HistorianFu:OnDataUpdate()

end;
 
 
-- *************************************
-- * OnTextUpdate
-- *************************************
function HistorianFu:OnTextUpdate()
	self:SetText("Historian");
end;
 

-- *************************************
-- * OnStatsUpdated
-- *************************************
function HistorianFu:OnStatsUpdated()
	self:Update();
end;


-- *************************************
-- * FormatMoney
-- *************************************
function HistorianFu:FormatMoney(amount)
	-- Gold
	if (amount >= 10000) then
		return string.format("%d", amount / 10000) .. " Gold";
	end;

	-- Silver
	if (amount >= 100) then
		return string.format("%d", amount / 100) .. " Silver";
	end;
	
	-- Copper
	return amount .. " Copper";
end;


 

-- *************************************
-- * OnTooltipUpdate
-- *************************************
function HistorianFu:OnTooltipUpdate()

	-- *******************	
	-- FORTUNE
	-- *******************	

	local moneyCategory = tablet:AddCategory(
		'text', "Fortune",
		'columns', 2,
		'child_textR', 1,
		'child_textG', 1,
		'child_textB', 0,
		'child_text2R', 1,
		'child_text2G', 1,
		'child_text2B', 1
	)
	
	moneyCategory:AddLine(
		'text', "Money at peak:",
		'text2', self:FormatMoney(Historian.db.char.Loot.MostMoneyEver)
	)
	
	
	-- *******************	
	-- ITEMS LOOTED
	-- *******************	

	local lootCategory = tablet:AddCategory(
		'text', "Items looted",
		'columns', 2,
		'child_textR', 1,
		'child_textG', 1,
		'child_textB', 0,
		'child_text2R', 1,
		'child_text2G', 1,
		'child_text2B', 1
	)
	
	local r,g,b = GetItemQualityColor(1);
      
	lootCategory:AddLine(
		'text', "Common:",
		'text2', Historian.db.char.Loot.ItemsOfQuality[1],
		'textR', r,
		'textG', g,
    	'textB', b
	)
	
	r,g,b = GetItemQualityColor(2);
	
	lootCategory:AddLine(
		'text', "Uncommon:",
		'text2', Historian.db.char.Loot.ItemsOfQuality[2],
		'textR', r,
		'textG', g,
    	'textB', b
	)
	
	r,g,b = GetItemQualityColor(3);
	
	lootCategory:AddLine(
		'text', "Rare:",
		'text2', Historian.db.char.Loot.ItemsOfQuality[3],
		'textR', r,
		'textG', g,
    	'textB', b
	)
	
	r,g,b = GetItemQualityColor(4);
	
	lootCategory:AddLine(
		'text', "Epic:",
		'text2', Historian.db.char.Loot.ItemsOfQuality[4],
		'textR', r,
		'textG', g,
    	'textB', b
	)

	r,g,b = GetItemQualityColor(5);

	if (Historian.db.char.Loot.ItemsOfQuality[5] > 0) then
		lootCategory:AddLine(
			'text', "Legendary:",
			'text2', Historian.db.char.Loot.ItemsOfQuality[5],
			'textR', r,
			'textG', g,
			'textB', b
		)
	end;
	
	r,g,b = GetItemQualityColor(6);
	
	if (Historian.db.char.Loot.ItemsOfQuality[6] > 0) then
		lootCategory:AddLine(
			'text', "Artifact:",
			'text2', Historian.db.char.Loot.ItemsOfQuality[6],
			'textR', r,
			'textG', g,
			'textB', b
		)
	end;	
	
	-- *******************	
	-- ACHIEVEMENTS
	-- *******************	

	local achievementsCategory = tablet:AddCategory(
		'text', "Achievements",
		'columns', 2,
		'child_textR', 1,
		'child_textG', 1,
		'child_textB', 0,
		'child_text2R', 1,
		'child_text2G', 1,
		'child_text2B', 1
	)
	
	achievementsCategory:AddLine(
		'text', "Quests completed:",
		'text2', Historian.db.char.Advancement.QuestsCompleted
	)
	
	achievementsCategory:AddLine(
		'text', "Recipes learned:",
		'text2', Historian.db.char.Advancement.RecipesLearned
	)
	
	achievementsCategory:AddLine(
		'text', "Areas discovered:",
		'text2', Historian.db.char.Discoveries.Areas
	)
	
	achievementsCategory:AddLine(
		'text', "Total mobs killed:",
		'text2', Historian.db.char.Kills.Total
	)
	
	
	-- TODO: Show level information somehow
--	achievementsCategory:AddLine(
--		'text', "Level 1-10",
--		'text2', "TODO"
--	)
	
	

	-- *******************	
	-- DISAPPOINTMENTS
	-- *******************	

	local disappointmentsCategory = tablet:AddCategory(
		'text', "Disappointments",
		'columns', 2,
		'child_textR', 1,
		'child_textG', 1,
		'child_textB', 0,
		'child_text2R', 1,
		'child_text2G', 1,
		'child_text2B', 1
	)
	
	if (Historian:AsNumber(Historian.db.char.EnvironmentalDamage.Drowning.Times) > 0) then
		disappointmentsCategory:AddLine(
			'text', "Drowning:",
			'text2', string.format("%d times (%d damage)", Historian.db.char.EnvironmentalDamage.Drowning.Times, Historian.db.char.EnvironmentalDamage.Drowning.TotalDamage)
		)
	end;
	
	if (Historian:AsNumber(Historian.db.char.EnvironmentalDamage.Fatique.Times) > 0) then
		disappointmentsCategory:AddLine(
			'text', "Fatiqued:",
			'text2', string.format("%d times (%d damage)", Historian.db.char.EnvironmentalDamage.Fatique.Times, Historian.db.char.EnvironmentalDamage.Fatique.TotalDamage)
		)
	end;
	
	if (Historian:AsNumber(Historian.db.char.EnvironmentalDamage.Falling.Times) > 0) then
		disappointmentsCategory:AddLine(
			'text', "Fallen down:",
			'text2', string.format("%d times (%d damage)", Historian.db.char.EnvironmentalDamage.Falling.Times, Historian.db.char.EnvironmentalDamage.Falling.TotalDamage)
		)
	end;
	
	if (Historian:AsNumber(Historian.db.char.EnvironmentalDamage.Fire.Times) > 0) then
		disappointmentsCategory:AddLine(
			'text', "Burnt:",
			'text2', string.format("%d times (%d damage)", Historian.db.char.EnvironmentalDamage.Fire.Times, Historian.db.char.EnvironmentalDamage.Fire.TotalDamage)
		)
	end;
	
	if (Historian:AsNumber(Historian.db.char.EnvironmentalDamage.Lava.Times) > 0) then
		disappointmentsCategory:AddLine(
			'text', "Tasted lava:",
			'text2', string.format("%d times (%d damage)", Historian.db.char.EnvironmentalDamage.Lava.Times, Historian.db.char.EnvironmentalDamage.Lava.TotalDamage)
		)
	end;
		
	if (Historian:AsNumber(Historian.db.char.EnvironmentalDamage.Slime.Times) > 0) then
		disappointmentsCategory:AddLine(
			'text', "Bathed in slime:",
			'text2', string.format("%d times (%d damage)", Historian.db.char.EnvironmentalDamage.Slime.Times, Historian.db.char.EnvironmentalDamage.Slime.TotalDamage)
		)
	end;
	
	if (Historian:AsNumber(Historian.db.char.Advancement.TotalDeaths) > 0) then
		disappointmentsCategory:AddLine(
			'text', "Just plain dead:",
			'text2', string.format("%d times", Historian:AsNumber(Historian.db.char.Advancement.TotalDeaths))
		)
	end;	
	
	-- *******************	
	-- HABITS
	-- *******************	

	local habitsCategory = tablet:AddCategory(
		'text', "Habits",
		'columns', 2,
		'child_textR', 1,
		'child_textG', 1,
		'child_textB', 0,
		'child_text2R', 1,
		'child_text2G', 1,
		'child_text2B', 1
	)

	if (Historian.db.char.Follow.MostFollowed.Count > 0) then
		habitsCategory:AddLine(
			'text', "Most followed player:",
			'text2', string.format("%s (%d times)", Historian.db.char.Follow.MostFollowed.Name, Historian.db.char.Follow.MostFollowed.Count)
		)
	end;
	
	if (Historian.db.char.Kills.Favorite.Count > 0) then
		habitsCategory:AddLine(
			'text', "Favorite prey:",
			'text2', string.format("%s (%d killed)", Historian.db.char.Kills.Favorite.Name, Historian.db.char.Kills.Favorite.Count)
		)
	end;

	habitsCategory:AddLine(
			'text', "Had a snack:",
			'text2', string.format("%d times", Historian.db.char.Consumption.Food)
		)

	habitsCategory:AddLine(
			'text', "Had a drink:",
			'text2', string.format("%d times", Historian.db.char.Consumption.Drink)
		)

	habitsCategory:AddLine(
			'text', "Jumps:",
			'text2', tostring(Historian.db.char.Jumps)
		)

end;